@@ -4,6 +4,7 @@ import os
 import sys
 import time
 import asyncio
+import signal
 import base64
 import yaml
 import traceback
@@ -36,7 +37,7 @@ class SavedQuestion:
 
 sayhi = {
     'hi': '''
-Hello, this is an intelligent question and answer robot. Is there anything I can help you with?
+Hello, this is an intelligent robot. Is there anything I can help you with?
 
 here is a list of things that I As an AI language model, can do, along with a brief explanation of each:
 
@@ -64,7 +65,7 @@ here is a list of things that I As an AI language model, can do, along with a br
     ''',
 
     '你好': '''
-你好，这是一个智能问答机器人，请问有什么可以帮到你的吗？
+你好，这是一个智能机器人，请问有什么可以帮到你的吗？
 
 以下是我可以做的事情：
 
@@ -176,6 +177,21 @@ class MixinBot(MixinWSApi):
         
         assert self.bots
 
+        loop = asyncio.get_running_loop()
+        loop.add_signal_handler(signal.SIGINT, lambda: asyncio.create_task(self.handle_signal(signal.SIGINT)))
+        loop.add_signal_handler(signal.SIGTERM, lambda: asyncio.create_task(self.handle_signal(signal.SIGTERM)))
+
+    async def handle_signal(self, signum):
+        logger.info("+++++++handle signal: %s", signum)
+        for bot in self.bots:
+            logger.info("++close bot: %s", bot)
+            await bot.close()
+        loop = asyncio.get_running_loop()
+        loop.remove_signal_handler(signal.SIGINT)
+        loop.remove_signal_handler(signal.SIGTERM)
+        sys.exit(0)
+        # os.kill(os.getpid(), signal.SIGINT)
+
     def choose_bot(self, user_id):
         bots = []
         for bot in self.bots:
